Changelog
=========


(unreleased)
------------
- Docs(README): global links for pipy. [Aditya NG]
- Merge pull request #1 from
  AdityaNG/dependabot/github_actions/actions/setup-python-5. [Aditya]

  Bump actions/setup-python from 4 to 5
- Bump actions/setup-python from 4 to 5. [dependabot[bot]]

  Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4 to 5.
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: actions/setup-python
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #2 from
  AdityaNG/dependabot/github_actions/stefanzweifel/git-auto-commit-
  action-5. [Aditya]

  Bump stefanzweifel/git-auto-commit-action from 4 to 5
- Bump stefanzweifel/git-auto-commit-action from 4 to 5.
  [dependabot[bot]]

  Bumps [stefanzweifel/git-auto-commit-action](https://github.com/stefanzweifel/git-auto-commit-action) from 4 to 5.
  - [Release notes](https://github.com/stefanzweifel/git-auto-commit-action/releases)
  - [Changelog](https://github.com/stefanzweifel/git-auto-commit-action/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/stefanzweifel/git-auto-commit-action/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: stefanzweifel/git-auto-commit-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #3 from
  AdityaNG/dependabot/github_actions/actions/checkout-4. [Aditya]

  Bump actions/checkout from 3 to 4
- Bump actions/checkout from 3 to 4. [dependabot[bot]]

  Bumps [actions/checkout](https://github.com/actions/checkout) from 3 to 4.
  - [Release notes](https://github.com/actions/checkout/releases)
  - [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/actions/checkout/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: actions/checkout
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #4 from
  AdityaNG/dependabot/github_actions/codecov/codecov-action-4. [Aditya]

  Bump codecov/codecov-action from 3 to 4
- Bump codecov/codecov-action from 3 to 4. [dependabot[bot]]

  Bumps [codecov/codecov-action](https://github.com/codecov/codecov-action) from 3 to 4.
  - [Release notes](https://github.com/codecov/codecov-action/releases)
  - [Changelog](https://github.com/codecov/codecov-action/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/codecov/codecov-action/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: codecov/codecov-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #5 from
  AdityaNG/dependabot/github_actions/softprops/action-gh-release-2.
  [Aditya]

  build(deps): bump softprops/action-gh-release from 1 to 2
- Build(deps): bump softprops/action-gh-release from 1 to 2.
  [dependabot[bot]]

  Bumps [softprops/action-gh-release](https://github.com/softprops/action-gh-release) from 1 to 2.
  - [Release notes](https://github.com/softprops/action-gh-release/releases)
  - [Changelog](https://github.com/softprops/action-gh-release/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/softprops/action-gh-release/compare/v1...v2)

  ---
  updated-dependencies:
  - dependency-name: softprops/action-gh-release
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Update LICENSE. [Aditya]
- Ci(.github/workflows/main.yml): env openai key. [Aditya NG]
- Fix(myugpt/helper.py): mac does not support local text embeddings
  model, switched out for an api call. [Aditya NG]
- Build(requirements.txt): updated and tested. [Aditya NG]
- Test(myugpt/): tests for codebase, coverage above 70% [Aditya NG]
- Feat(ollama): support added to query ollama models. [Aditya NG]
- Feat(gpt): stream thought. [Aditya NG]
- Initial commit. [Aditya NG]
- ✅ Ready to clone and code. [AdityaNG]
- Initial commit. [Aditya]


